@@ -36,11 +36,11 @@ Backup::EZ - Simple backups based on rsync
 
 =head1 VERSION
 
-Version 0.33
+Version 0.34
 
 =cut
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 =head1 SYNOPSIS
 
@@ -353,7 +353,7 @@ sub _rsync2 {
     # uncoverable branch false
     if ( $self->_is_unit_test ) {
         $cmd = sprintf(
-            'rsync %s %s "%s/" "%s%s"',
+            'rsync -s %s %s "%s/" "%s%s"',
             join(' ', @$extra_opts),
             $archive_opts,               # archive options
             $dir,                        # src dir
@@ -363,7 +363,7 @@ sub _rsync2 {
     }
     else {
         $cmd = sprintf(
-            'rsync %s %s -e ssh "%s/" %s:"%s%s"',
+            'rsync -s %s %s -e ssh "%s/" %s:"%s%s"',
             join( ' ', @{$extra_opts} ),    # extra rsync options
             $archive_opts,                  # archive options
             $dir,                           # src dir
